@@ -44,7 +44,7 @@ int main(int argc, char **argv)
                      i18n("KDiamond, a three-in-a-row game."),
                      KAboutLicense::GPL, i18n("(C) 2008-2010 Stefan Majewsky and others"),
                      QString(),
-                     QStringLiteral("https://kde.org/applications/games/org.kde.kdiamond"));
+                     QStringLiteral("https://apps.kde.org/kdiamond"));
     about.addAuthor(i18n("Stefan Majewsky"), i18n("Original author and current maintainer"), QStringLiteral("majewsky@gmx.net"));
     about.addAuthor(i18n("Paul Bunbury"), i18n("Gameplay refinement"), QStringLiteral("happysmileman@googlemail.com"));
     about.addCredit(i18n("Eugene Trounev"), i18n("Default theme"), QStringLiteral("eugene.trounev@gmail.com"));
